Automobile insurance Zaire 1974: The data show the number of automobile insurance third party liability portfolios in Zaire 1974
Description
The function gives the number of automobile insurance third-party liability portfolios in Zaire 1974.
Usage
data_claim2
Value
data_claim2 gives the number of automobile insurance third-party liability portfolios in Zaire 1974.
Arguments
data_claim2
A vector of (non-negative integer) count values.
Author
Muhammad Imran
R implementation and documentation: Muhammad Imran [email protected].
Details
The data show the number of automobile insurance third-party liability portfolios in Zaire 1974. They were used by Denuit (1997) and fitted by the zero-inflated Poisson (ZIP) distribution.
References
Denuit, M. (1997). A new distribution of Poisson-type for the number of claims. ASTIN Bulletin: The Journal of the IAA, 27(2), 229-242.