| Child per woman | R Documentation |
The function gives the observed number of children per woman.
data_child
data_child |
A vector of (non-negative integer) count values. |
The data show the observed number of children per woman. They were used by Melkersson and Rooth (2000) and fitted by the inflated count data models.
data_child gives the observed number of children per woman.
Muhammad Imran
R implementation and documentation: Muhammad Imran imranshakoor84@yahoo.com.
Melkersson, M., & Rooth, D. O. (2000). Modeling female fertility using inflated count data models. Journal of Population Economics, 13, 189-203.
data_bihar, data_orissa
x<-data_child
summary(x)
table (x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.